@@ -4,36 +4,38 @@ from functools import lru_cache
 from sys import intern
 from typing import TYPE_CHECKING, Callable, Iterable, Sequence
 
-from rich.console import Console
+import rich.repr
 from rich.segment import Segment
-from rich.style import Style
-from rich.text import Text
+from rich.style import Style as RichStyle
+from rich.terminal_theme import TerminalTheme
 
-from . import log
-from ._ansi_theme import DEFAULT_TERMINAL_THEME
-from ._border import get_box, render_border_label, render_row
-from ._context import active_app
-from ._opacity import _apply_opacity
-from ._segment_tools import line_pad, line_trim
-from .color import Color
-from .constants import DEBUG
-from .filter import LineFilter
-from .geometry import Region, Size, Spacing
-from .renderables.text_opacity import TextOpacity
-from .renderables.tint import Tint
-from .strip import Strip
+from textual import log
+from textual._ansi_theme import DEFAULT_TERMINAL_THEME
+from textual._border import get_box, render_border_label, render_row
+from textual._context import active_app
+from textual._opacity import _apply_opacity
+from textual._segment_tools import apply_hatch, line_pad, line_trim
+from textual.color import TRANSPARENT, Color
+from textual.constants import DEBUG
+from textual.content import Content
+from textual.filter import LineFilter
+from textual.geometry import Region, Size, Spacing
+from textual.renderables.text_opacity import TextOpacity
+from textual.renderables.tint import Tint
+from textual.strip import Strip
+from textual.style import Style
 
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
 
-    from .css.styles import StylesBase
-    from .widget import Widget
+    from textual.css.styles import StylesBase
+    from textual.widget import Widget
 
 RenderLineCallback: TypeAlias = Callable[[int], Strip]
 
 
 @lru_cache(1024 * 8)
-def make_blank(width, style: Style) -> Segment:
+def make_blank(width, style: RichStyle) -> Segment:
     """Make a blank segment.
 
     Args:
@@ -46,6 +48,7 @@ def make_blank(width, style: Style) -> Segment:
     return Segment(intern(" " * width), style)
 
 
+@rich.repr.auto(angular=True)
 class StylesCache:
     """Responsible for rendering CSS Styles and keeping a cache of rendered lines.
 
@@ -76,6 +79,11 @@ class StylesCache:
         self._dirty_lines: set[int] = set()
         self._width = 1
 
+    def __rich_repr__(self) -> rich.repr.Result:
+        if self._dirty_lines:
+            yield "dirty", self._dirty_lines
+        yield "width", self._width, 1
+
     def set_dirty(self, *regions: Region) -> None:
         """Add a dirty regions."""
         if regions:
@@ -122,7 +130,6 @@ class StylesCache:
             base_background,
             background,
             widget.render_line,
-            widget.app.console,
             (
                 None
                 if border_title is None
@@ -144,7 +151,9 @@ class StylesCache:
             crop=crop,
             filters=widget.app._filters,
             opacity=widget.opacity,
+            ansi_theme=widget.app.ansi_theme,
         )
+
         if widget.auto_links:
             hover_style = widget.hover_style
             if (
@@ -168,14 +177,14 @@ class StylesCache:
         base_background: Color,
         background: Color,
         render_content_line: RenderLineCallback,
-        console: Console,
-        border_title: tuple[Text, Color, Color, Style] | None,
-        border_subtitle: tuple[Text, Color, Color, Style] | None,
+        border_title: tuple[Content, Color, Color, Style] | None,
+        border_subtitle: tuple[Content, Color, Color, Style] | None,
         content_size: Size | None = None,
         padding: Spacing | None = None,
         crop: Region | None = None,
         filters: Sequence[LineFilter] | None = None,
         opacity: float = 1.0,
+        ansi_theme: TerminalTheme = DEFAULT_TERMINAL_THEME,
     ) -> list[Strip]:
         """Render a widget content plus CSS styles.
 
@@ -213,6 +222,9 @@ class StylesCache:
 
         is_dirty = self._dirty_lines.__contains__
         render_line = self.render_line
+        apply_filters = (
+            [] if filters is None else [filter for filter in filters if filter.enabled]
+        )
         for y in crop.line_range:
             if is_dirty(y) or y not in self._cache:
                 strip = render_line(
@@ -224,18 +236,17 @@ class StylesCache:
                     base_background,
                     background,
                     render_content_line,
-                    console,
                     border_title,
                     border_subtitle,
                     opacity,
+                    ansi_theme,
                 )
                 self._cache[y] = strip
             else:
                 strip = self._cache[y]
 
-            if filters:
-                for filter in filters:
-                    strip = strip.apply_filter(filter, background)
+            for filter in apply_filters:
+                strip = strip.apply_filter(filter, background)
 
             if DEBUG:
                 if any([not (segment.control or segment.text) for segment in strip]):
@@ -261,10 +272,10 @@ class StylesCache:
         base_background: Color,
         background: Color,
         render_content_line: Callable[[int], Strip],
-        console: Console,
-        border_title: tuple[Text, Color, Color, Style] | None,
-        border_subtitle: tuple[Text, Color, Color, Style] | None,
+        border_title: tuple[Content, Color, Color, Style] | None,
+        border_subtitle: tuple[Content, Color, Color, Style] | None,
         opacity: float,
+        ansi_theme: TerminalTheme,
     ) -> Strip:
         """Render a styled line.
 
@@ -306,10 +317,21 @@ class StylesCache:
             (outline_left, outline_left_color),
         ) = styles.outline
 
-        from_color = Style.from_color
+        from_color = RichStyle.from_color
 
-        inner = from_color(bgcolor=(base_background + background).rich_color)
-        outer = from_color(bgcolor=base_background.rich_color)
+        inner = Style(background=(base_background + background))
+        outer = Style(background=base_background)
+
+        def line_post(segments: Iterable[Segment]) -> Iterable[Segment]:
+            """Apply effects to segments inside the border."""
+            if styles.has_rule("hatch") and styles.hatch != "none":
+                character, color = styles.hatch
+                if character != " " and color.a > 0:
+                    hatch_style = from_color(
+                        (background + color).rich_color, background.rich_color
+                    )
+                    return apply_hatch(segments, character, hatch_style)
+            return segments
 
         def post(segments: Iterable[Segment]) -> Iterable[Segment]:
             """Post process segments to apply opacity and tint.
@@ -320,6 +342,7 @@ class StylesCache:
             Returns:
                 New list of segments
             """
+
             try:
                 app = active_app.get()
                 ansi_theme = app.ansi_theme
@@ -327,7 +350,9 @@ class StylesCache:
                 ansi_theme = DEFAULT_TERMINAL_THEME
 
             if styles.tint.a:
-                segments = Tint.process_segments(segments, styles.tint, ansi_theme)
+                segments = Tint.process_segments(
+                    segments, styles.tint, ansi_theme, background
+                )
             if opacity != 1.0:
                 segments = _apply_opacity(segments, base_background, opacity)
             return segments
@@ -335,11 +360,12 @@ class StylesCache:
         line: Iterable[Segment]
         # Draw top or bottom borders (A)
         if (border_top and y == 0) or (border_bottom and y == height - 1):
+
             is_top = y == 0
             border_color = base_background + (
                 border_top_color if is_top else border_bottom_color
             ).multiply_alpha(opacity)
-            border_color_as_style = from_color(color=border_color.rich_color)
+            border_color_as_style = Style(foreground=border_color)
             border_edge_type = border_top if is_top else border_bottom
             has_left = border_left != ""
             has_right = border_right != ""
@@ -349,19 +375,20 @@ class StylesCache:
             else:
                 label, label_color, label_background, style = border_label
                 base_label_background = base_background + background
-                style += Style.from_color(
+                style += Style(
                     (
-                        (base_label_background + label_color).rich_color
-                        if label_color.a
-                        else None
+                        (base_label_background + label_background)
+                        if label_background.a
+                        else TRANSPARENT
                     ),
                     (
-                        (base_label_background + label_background).rich_color
-                        if label_background.a
-                        else None
+                        (base_label_background + label_color)
+                        if label_color.a
+                        else TRANSPARENT
                     ),
                 )
                 render_label = (label, style)
+
             # Try to save time with expensive call to `render_border_label`:
             if render_label:
                 label_segments = render_border_label(
@@ -372,7 +399,6 @@ class StylesCache:
                     inner,
                     outer,
                     border_color_as_style,
-                    console,
                     has_left,
                     has_right,
                 )
@@ -400,27 +426,24 @@ class StylesCache:
         elif (pad_top and y < gutter.top) or (
             pad_bottom and y >= height - gutter.bottom
         ):
-            background_style = from_color(bgcolor=background.rich_color)
-            left_style = from_color(
-                color=(
-                    base_background + border_left_color.multiply_alpha(opacity)
-                ).rich_color
+            background_rich_style = from_color(bgcolor=background.rich_color)
+            left_style = Style(
+                foreground=base_background + border_left_color.multiply_alpha(opacity)
             )
             left = get_box(border_left, inner, outer, left_style)[1][0]
-            right_style = from_color(
-                color=(
-                    base_background + border_right_color.multiply_alpha(opacity)
-                ).rich_color
+            right_style = Style(
+                foreground=base_background + border_right_color.multiply_alpha(opacity)
             )
             right = get_box(border_right, inner, outer, right_style)[1][2]
             if border_left and border_right:
-                line = [left, make_blank(width - 2, background_style), right]
+                line = [left, make_blank(width - 2, background_rich_style), right]
             elif border_left:
-                line = [left, make_blank(width - 1, background_style)]
+                line = [left, make_blank(width - 1, background_rich_style)]
             elif border_right:
-                line = [make_blank(width - 1, background_style), right]
+                line = [make_blank(width - 1, background_rich_style), right]
             else:
-                line = [make_blank(width, background_style)]
+                line = [make_blank(width, background_rich_style)]
+            line = line_post(line)
         else:
             # Content with border and padding (C)
             content_y = y - gutter.top
@@ -428,25 +451,25 @@ class StylesCache:
                 line = render_content_line(y - gutter.top)
                 line = line.adjust_cell_length(content_width)
             else:
-                line = [make_blank(content_width, inner)]
+                line = [make_blank(content_width, inner.rich_style)]
             if inner:
-                line = Segment.apply_style(line, inner)
+                line = Segment.apply_style(line, inner.rich_style)
             if styles.text_opacity != 1.0:
-                line = TextOpacity.process_segments(line, styles.text_opacity)
-            line = line_pad(line, pad_left, pad_right, inner)
+                line = TextOpacity.process_segments(
+                    line, styles.text_opacity, ansi_theme
+                )
+            line = line_post(line_pad(line, pad_left, pad_right, inner.rich_style))
 
             if border_left or border_right:
                 # Add left / right border
-                left_style = from_color(
-                    (
-                        base_background + border_left_color.multiply_alpha(opacity)
-                    ).rich_color
+                left_style = Style(
+                    foreground=base_background
+                    + border_left_color.multiply_alpha(opacity)
                 )
                 left = get_box(border_left, inner, outer, left_style)[1][0]
-                right_style = from_color(
-                    (
-                        base_background + border_right_color.multiply_alpha(opacity)
-                    ).rich_color
+                right_style = Style(
+                    foreground=base_background
+                    + border_right_color.multiply_alpha(opacity)
                 )
                 right = get_box(border_right, inner, outer, right_style)[1][2]
 
@@ -465,7 +488,7 @@ class StylesCache:
                 outline_top if y == 0 else outline_bottom,
                 inner,
                 outer,
-                from_color(color=(base_background + outline_color).rich_color),
+                Style(foreground=base_background + outline_color),
             )
             line = render_row(
                 box_segments[0 if y == 0 else 2],
@@ -477,9 +500,9 @@ class StylesCache:
 
         elif outline_left or outline_right:
             # Lines in side outline
-            left_style = from_color((base_background + outline_left_color).rich_color)
+            left_style = Style(foreground=(base_background + outline_left_color))
             left = get_box(outline_left, inner, outer, left_style)[1][0]
-            right_style = from_color((base_background + outline_right_color).rich_color)
+            right_style = Style(foreground=(base_background + outline_right_color))
             right = get_box(outline_right, inner, outer, right_style)[1][2]
             line = line_trim(list(line), outline_left != "", outline_right != "")
             if outline_left and outline_right:
